==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Homepage',
	'article' => 'Artikel',
	'articles' => 'Artikelen',
	'articles_auteur' => 'Artikelen vun dësem Auteur',
	'articles_populaires' => 'Déi beléifsten Artikelen',
	'articles_rubrique' => 'Artikelen aus dëser Rubrik',
	'aucun_article' => 'Et gëtt keen Artikel op dëser Adress',
	'aucun_auteur' => 'Et gëtt keen Auteur op dëser Adress',
	'aucun_site' => 'Et gëtt keen Site op dëser Adress',
	'aucune_breve' => 'Et gëtt keng Kuerzmeldung op dëser Adress',
	'aucune_rubrique' => 'Et gëtt keng Rubrik op dëser Adress',
	'auteur' => 'Auteur',
	'autres' => 'Anerer',
	'autres_breves' => 'Aner Kuerzmeldungen',
	'autres_groupes_mots_clefs' => 'Aner Schlësselwierder-Gruppen',
	'autres_sites' => 'Aner Siten',

	// B
	'bonjour' => 'Bonjour',

	// C
	'commenter_site' => 'Dësen Site kommentéieren',
	'contact' => 'Kontakt',
	'copie_document_impossible' => 'Onméiglech dat Dokument ze kopéieren',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Läscht Ännerung',
	'dernieres_breves' => 'Läscht Kuerzmeldungen',
	'derniers_articles' => 'Läscht Artikelen',
	'derniers_commentaires' => 'Läscht Kommentaren',
	'derniers_messages_forum' => 'Läscht Messagen aus de Forumen',

	// E
	'edition_mode_texte' => 'Ännerung am Text-Modus vun',
	'en_reponse' => 'Als Äntwert un:',
	'en_resume' => 'An der Zesummefaassung',
	'envoyer_message' => 'E Message schécken',
	'espace_prive' => 'Privaten Deel',

	// F
	'formats_acceptes' => 'Akzeptéiert Formater: @formats@.',

	// H
	'hierarchie_site' => 'Struktur vum Site',

	// J
	'jours' => 'Deg',

	// L
	'lien_connecter' => 'Verbannen',

	// M
	'meme_auteur' => 'Vum selwechten Auteur',
	'meme_rubrique' => 'An der selwechter Rubrik',
	'memes_auteurs' => 'Vun de selwechten Auteuren',
	'message' => 'Message',
	'messages_forum' => 'Messagen',
	'messages_recents' => 'Läscht Messagen aus de Forumen',
	'mots_clef' => 'Schlësselwuert',
	'mots_clefs' => 'Schlësselwierder',
	'mots_clefs_meme_groupe' => 'Schlësselwierder aus dem selwechte Grupp',

	// N
	'navigation' => 'Navigatioun',
	'nom' => 'Numm',
	'nouveautes' => 'Neiegkeeten',
	'nouveautes_web' => 'Internet-Neiegkeeten',
	'nouveaux_articles' => 'Nei Artikelen',
	'nouvelles_breves' => 'Nei Kuerzmeldungen',

	// P
	'page_precedente' => 'läscht Säit',
	'page_suivante' => 'nächst Säit',
	'par_auteur' => 'vum',
	'participer_site' => 'Dir kënnt un dësem Site matschaffen an är Artikelen proposéieren andeem der Iech hei aschreift. Dir kritt direkt en Email mat ärem Login fir de privaten Deel vum Site.',
	'plan_site' => 'Plang vum Site',
	'popularite' => 'Popularitéit',
	'poster_message' => 'E Message schécken',
	'proposer_site' => 'Dir kënnt e Site fir dës Rubrik uginn:',

	// R
	'repondre_article' => 'Op dësen Artikel äntweren',
	'repondre_breve' => 'Op dës Kuerzmeldung äntweren',
	'resultats_recherche' => 'Resultater vun der Sich',
	'retour_debut_forums' => 'Zeréck op den Ufank vun de Forumen',
	'rubrique' => 'Rubrik',
	'rubriques' => 'Rubriken',

	// S
	'signatures_petition' => 'Ënnerschrëften',
	'site_realise_avec_spip' => 'Dëse Site ass mat SPIP realiséiert',
	'sites_web' => 'Internet-Siten',
	'sous_rubriques' => 'Ënner-Rubriken',
	'spam' => 'Spam',
	'suite' => 'weider',
	'sur_web' => 'Um Internet',
	'syndiquer_rubrique' => 'Dës Rubrik syndikaliséieren',
	'syndiquer_site' => 'De ganze Site syndikaliséieren',

	// T
	'texte_lettre_information' => 'Hei ass d’Newsletter vum Site',
	'texte_lettre_information_2' => 'Dës Newsletter ass d’Lëscht vun de verëffentlechten Ännerungen zënter',

	// V
	'ver_imprimer' => 'Drock-Versioun',
	'voir_en_ligne' => 'Online gesinn',
	'voir_squelette' => 'd’Skelett vun dëser Säit weisen'
);

==> spip_4.4.8+dfsg.orig.tar.xz: ecrire/lang/public_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Homepage',
	'article' => 'Artikel',
	'articles' => 'Artikelen',
	'articles_auteur' => 'Artikelen vun dësem Auteur',
	'articles_populaires' => 'Déi beléifsten Artikelen',
	'articles_rubrique' => 'Artikelen aus dëser Rubrik',
	'aucun_article' => 'Et gëtt keen Artikel op dëser Adress',
	'aucun_auteur' => 'Et gëtt keen Auteur op dëser Adress',
	'aucun_site' => 'Et gëtt keen Site op dëser Adress',
	'aucune_breve' => 'Et gëtt keng Kuerzmeldung op dëser Adress',
	'aucune_rubrique' => 'Et gëtt keng Rubrik op dëser Adress',
	'auteur' => 'Auteur',
	'autres' => 'Anerer',
	'autres_breves' => 'Aner Kuerzmeldungen',
	'autres_groupes_mots_clefs' => 'Aner Schlësselwierder-Gruppen',
	'autres_sites' => 'Aner Siten',

	// B
	'bonjour' => 'Bonjour',

	// C
	'commenter_site' => 'Dësen Site kommentéieren',
	'contact' => 'Kontakt',
	'copie_document_impossible' => 'Onméiglech dat Dokument ze kopéieren',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Läscht Ännerung',
	'dernieres_breves' => 'Läscht Kuerzmeldungen',
	'derniers_articles' => 'Läscht Artikelen',
	'derniers_commentaires' => 'Läscht Kommentaren',
	'derniers_messages_forum' => 'Läscht Messagen aus de Forumen',

	// E
	'edition_mode_texte' => 'Ännerung am Text-Modus vun',
	'en_reponse' => 'Als Äntwert un:',
	'en_resume' => 'An der Zesummefaassung',
	'envoyer_message' => 'E Message schécken',
	'espace_prive' => 'Privaten Deel',

	// F
	'formats_acceptes' => 'Akzeptéiert Formater: @formats@.',

	// H
	'hierarchie_site' => 'Struktur vum Site',

	// J
	'jours' => 'Deg',

	// L
	'lien_connecter' => 'Verbannen',

	// M
	'meme_auteur' => 'Vum selwechten Auteur',
	'meme_rubrique' => 'An der selwechter Rubrik',
	'memes_auteurs' => 'Vun de selwechten Auteuren',
	'message' => 'Message',
	'messages_forum' => 'Messagen',
	'messages_recents' => 'Läscht Messagen aus de Forumen',
	'mots_clef' => 'Schlësselwuert',
	'mots_clefs' => 'Schlësselwierder',
	'mots_clefs_meme_groupe' => 'Schlësselwierder aus dem selwechte Grupp',

	// N
	'navigation' => 'Navigatioun',
	'nom' => 'Numm',
	'nouveautes' => 'Neiegkeeten',
	'nouveautes_web' => 'Internet-Neiegkeeten',
	'nouveaux_articles' => 'Nei Artikelen',
	'nouvelles_breves' => 'Nei Kuerzmeldungen',

	// P
	'page_precedente' => 'läscht Säit',
	'page_suivante' => 'nächst Säit',
	'par_auteur' => 'vum',
	'participer_site' => 'Dir kënnt un dësem Site matschaffen an är Artikelen proposéieren andeem der Iech hei aschreift. Dir kritt direkt en Email mat ärem Login fir de privaten Deel vum Site.',
	'plan_site' => 'Plang vum Site',
	'popularite' => 'Popularitéit',
	'poster_message' => 'E Message schécken',
	'proposer_site' => 'Dir kënnt e Site fir dës Rubrik uginn:',

	// R
	'repondre_article' => 'Op dësen Artikel äntweren',
	'repondre_breve' => 'Op dës Kuerzmeldung äntweren',
	'resultats_recherche' => 'Resultater vun der Sich',
	'retour_debut_forums' => 'Zeréck op den Ufank vun de Forumen',
	'rubrique' => 'Rubrik',
	'rubriques' => 'Rubriken',

	// S
	'signatures_petition' => 'Ënnerschrëften',
	'site_realise_avec_spip' => 'Dëse Site ass mat SPIP realiséiert',
	'sites_web' => 'Internet-Siten',
	'sous_rubriques' => 'Ënner-Rubriken',
	'spam' => 'Spam',
	'suite' => 'weider',
	'sur_web' => 'Um Internet',
	'syndiquer_rubrique' => 'Dës Rubrik syndikaliséieren',
	'syndiquer_site' => 'De ganze Site syndikaliséieren',

	// T
	'texte_lettre_information' => 'Hei ass d’Newsletter vum Site',
	'texte_lettre_information_2' => 'Dës Newsletter ass d’Lëscht vun de verëffentlechten Ännerungen zënter',

	// V
	'ver_imprimer' => 'Drock-Versioun',
	'voir_en_ligne' => 'Online gesinn',
	'voir_squelette' => 'd’Skelett vun dëser Säit weisen',
];
